/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.validator;

/**                                                       
 * Contains validation methods for different unit tests.
 *
 * @version $Revision: 1649191 $
 */                                                       
public class ParameterValidatorImpl {

    /**
     * ValidatorParameter is valid.
     * 
     */
    public static boolean validateParameter(
        final java.lang.Object bean,
        final org.apache.commons.validator.Form form,
        final org.apache.commons.validator.Field field,
        final org.apache.commons.validator.Validator validator,
        final org.apache.commons.validator.ValidatorAction action,
        final org.apache.commons.validator.ValidatorResults results,
        final java.util.Locale locale)
        throws Exception {

        return true;
    }
}
